==> openshift-model-operatorhub-5.11.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/CSVDescriptionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSVDescriptionBuilder extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluentImpl<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder>{
  public CSVDescriptionBuilder() {
    this(false);
  }
  public CSVDescriptionBuilder(java.lang.Boolean validationEnabled) {
    this(new CSVDescription(), validationEnabled);
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSVDescription(), validationEnabled);
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription instance) {
    this(fluent, instance, false);
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withApiservicedefinitions(instance.getApiservicedefinitions()); 
    fluent.withCustomresourcedefinitions(instance.getCustomresourcedefinitions()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withInstallModes(instance.getInstallModes()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withLinks(instance.getLinks()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withMaturity(instance.getMaturity()); 
    fluent.withMinKubeVersion(instance.getMinKubeVersion()); 
    fluent.withNativeApis(instance.getNativeApis()); 
    fluent.withProvider(instance.getProvider()); 
    fluent.withRelatedImages(instance.getRelatedImages()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription instance) {
    this(instance,false);
  }
  public CSVDescriptionBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withApiservicedefinitions(instance.getApiservicedefinitions()); 
    this.withCustomresourcedefinitions(instance.getCustomresourcedefinitions()); 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withIcon(instance.getIcon()); 
    this.withInstallModes(instance.getInstallModes()); 
    this.withKeywords(instance.getKeywords()); 
    this.withLinks(instance.getLinks()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withMaturity(instance.getMaturity()); 
    this.withMinKubeVersion(instance.getMinKubeVersion()); 
    this.withNativeApis(instance.getNativeApis()); 
    this.withProvider(instance.getProvider()); 
    this.withRelatedImages(instance.getRelatedImages()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription build() {
    CSVDescription buildable = new CSVDescription(fluent.getAnnotations(),fluent.getApiservicedefinitions(),fluent.getCustomresourcedefinitions(),fluent.getDescription(),fluent.getDisplayName(),fluent.getIcon(),fluent.getInstallModes(),fluent.getKeywords(),fluent.getLinks(),fluent.getMaintainers(),fluent.getMaturity(),fluent.getMinKubeVersion(),fluent.getNativeApis(),fluent.getProvider(),fluent.getRelatedImages(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSVDescriptionBuilder that = (CSVDescriptionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.3.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/CSVDescriptionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CSVDescriptionBuilder extends CSVDescriptionFluentImpl<CSVDescriptionBuilder> implements VisitableBuilder<CSVDescription,CSVDescriptionBuilder>{
  public CSVDescriptionBuilder() {
    this(false);
  }
  public CSVDescriptionBuilder(Boolean validationEnabled) {
    this(new CSVDescription(), validationEnabled);
  }
  public CSVDescriptionBuilder(CSVDescriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public CSVDescriptionBuilder(CSVDescriptionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CSVDescription(), validationEnabled);
  }
  public CSVDescriptionBuilder(CSVDescriptionFluent<?> fluent,CSVDescription instance) {
    this(fluent, instance, false);
  }
  public CSVDescriptionBuilder(CSVDescriptionFluent<?> fluent,CSVDescription instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withApiservicedefinitions(instance.getApiservicedefinitions()); 
    fluent.withCustomresourcedefinitions(instance.getCustomresourcedefinitions()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withInstallModes(instance.getInstallModes()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withLinks(instance.getLinks()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withMaturity(instance.getMaturity()); 
    fluent.withMinKubeVersion(instance.getMinKubeVersion()); 
    fluent.withNativeApis(instance.getNativeApis()); 
    fluent.withProvider(instance.getProvider()); 
    fluent.withRelatedImages(instance.getRelatedImages()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSVDescriptionBuilder(CSVDescription instance) {
    this(instance,false);
  }
  public CSVDescriptionBuilder(CSVDescription instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withApiservicedefinitions(instance.getApiservicedefinitions()); 
    this.withCustomresourcedefinitions(instance.getCustomresourcedefinitions()); 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withIcon(instance.getIcon()); 
    this.withInstallModes(instance.getInstallModes()); 
    this.withKeywords(instance.getKeywords()); 
    this.withLinks(instance.getLinks()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withMaturity(instance.getMaturity()); 
    this.withMinKubeVersion(instance.getMinKubeVersion()); 
    this.withNativeApis(instance.getNativeApis()); 
    this.withProvider(instance.getProvider()); 
    this.withRelatedImages(instance.getRelatedImages()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CSVDescriptionFluent<?> fluent;
  Boolean validationEnabled;
  public CSVDescription build() {
    CSVDescription buildable = new CSVDescription(fluent.getAnnotations(),fluent.getApiservicedefinitions(),fluent.getCustomresourcedefinitions(),fluent.getDescription(),fluent.getDisplayName(),fluent.getIcon(),fluent.getInstallModes(),fluent.getKeywords(),fluent.getLinks(),fluent.getMaintainers(),fluent.getMaturity(),fluent.getMinKubeVersion(),fluent.getNativeApis(),fluent.getProvider(),fluent.getRelatedImages(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
